# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'ProductAttributeTypeTranslation'
        db.create_table(u'products_productattributetypetranslation', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('lang', self.gf('django.db.models.fields.CharField')(max_length=2)),
            ('related', self.gf('django.db.models.fields.related.ForeignKey')(related_name='translations', null=True, to=orm['products.ProductAttributeType'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal(u'products', ['ProductAttributeTypeTranslation'])

        # Adding model 'ProductAttributeType'
        db.create_table(u'products_productattributetype', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
        ))
        db.send_create_signal(u'products', ['ProductAttributeType'])

        # Adding M2M table for field values on 'ProductAttributeType'
        m2m_table_name = db.shorten_name(u'products_productattributetype_values')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('productattributetype', models.ForeignKey(orm[u'products.productattributetype'], null=False)),
            ('productattributevalue', models.ForeignKey(orm[u'products.productattributevalue'], null=False))
        ))
        db.create_unique(m2m_table_name, ['productattributetype_id', 'productattributevalue_id'])

        # Adding model 'ProductAttributeValue'
        db.create_table(u'products_productattributevalue', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['products.ProductAttributeType'], null=True)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=100)),
        ))
        db.send_create_signal(u'products', ['ProductAttributeValue'])

        # Adding model 'ProductAttributeFilter'
        db.create_table(u'products_productattributefilter', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('order_index', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal(u'products', ['ProductAttributeFilter'])

        # Adding M2M table for field attributes on 'ProductAttributeFilter'
        m2m_table_name = db.shorten_name(u'products_productattributefilter_attributes')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('productattributefilter', models.ForeignKey(orm[u'products.productattributefilter'], null=False)),
            ('productattributetype', models.ForeignKey(orm[u'products.productattributetype'], null=False))
        ))
        db.create_unique(m2m_table_name, ['productattributefilter_id', 'productattributetype_id'])

        # Adding M2M table for field categories on 'ProductAttributeFilter'
        m2m_table_name = db.shorten_name(u'products_productattributefilter_categories')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('productattributefilter', models.ForeignKey(orm[u'products.productattributefilter'], null=False)),
            ('productcategory', models.ForeignKey(orm[u'products.productcategory'], null=False))
        ))
        db.create_unique(m2m_table_name, ['productattributefilter_id', 'productcategory_id'])

        # Adding model 'ProductAttribute'
        db.create_table(u'products_productattribute', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('product', self.gf('django.db.models.fields.related.ForeignKey')(related_name='attributes', null=True, to=orm['products.Product'])),
            ('type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['products.ProductAttributeType'], null=True)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
        ))
        db.send_create_signal(u'products', ['ProductAttribute'])

        # Adding model 'ProductCategoryTranslation'
        db.create_table(u'products_productcategorytranslation', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('lang', self.gf('django.db.models.fields.CharField')(max_length=2)),
            ('related', self.gf('django.db.models.fields.related.ForeignKey')(related_name='translations', null=True, to=orm['products.ProductCategory'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('description', self.gf('django.db.models.fields.TextField')(default='', blank=True)),
            ('slug', self.gf('django.db.models.fields.CharField')(default='', max_length=255, blank=True)),
        ))
        db.send_create_signal(u'products', ['ProductCategoryTranslation'])

        # Adding model 'ProductCategory'
        db.create_table(u'products_productcategory', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('date_created', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('date_updated', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
            ('order_index', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('description', self.gf('django.db.models.fields.TextField')(default='', blank=True)),
            ('slug', self.gf('django.db.models.fields.CharField')(default='', max_length=255, blank=True)),
            ('image', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['filer.Image'], null=True, blank=True)),
            ('parent', self.gf('mptt.fields.TreeForeignKey')(blank=True, related_name='children', null=True, to=orm['products.ProductCategory'])),
            ('is_active', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('allow_filtering', self.gf('django.db.models.fields.BooleanField')(default=True)),
            (u'lft', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            (u'rght', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            (u'tree_id', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            (u'level', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
        ))
        db.send_create_signal(u'products', ['ProductCategory'])

        # Adding M2M table for field attribute_types on 'ProductCategory'
        m2m_table_name = db.shorten_name(u'products_productcategory_attribute_types')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('productcategory', models.ForeignKey(orm[u'products.productcategory'], null=False)),
            ('productattributetype', models.ForeignKey(orm[u'products.productattributetype'], null=False))
        ))
        db.create_unique(m2m_table_name, ['productcategory_id', 'productattributetype_id'])

        # Adding model 'ProductTranslation'
        db.create_table(u'products_producttranslation', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('lang', self.gf('django.db.models.fields.CharField')(max_length=2)),
            ('related', self.gf('django.db.models.fields.related.ForeignKey')(related_name='translations', null=True, to=orm['products.Product'])),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('long_title', self.gf('django.db.models.fields.CharField')(default='', max_length=255, null=True, blank=True)),
            ('slug', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('long_description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'products', ['ProductTranslation'])

        # Adding model 'Product'
        db.create_table(u'products_product', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('date_created', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('date_updated', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('long_title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('slug', self.gf('django.db.models.fields.CharField')(default='', max_length=255, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('long_description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('price', self.gf('django.db.models.fields.DecimalField')(max_digits=8, decimal_places=2)),
            ('price_discount', self.gf('django.db.models.fields.DecimalField')(default=0, max_digits=8, decimal_places=2)),
            ('discount', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('featured', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('sold', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('archived', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('sold_count', self.gf('django.db.models.fields.PositiveIntegerField')(default=0)),
        ))
        db.send_create_signal(u'products', ['Product'])

        # Adding M2M table for field categories on 'Product'
        m2m_table_name = db.shorten_name(u'products_product_categories')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('product', models.ForeignKey(orm[u'products.product'], null=False)),
            ('productcategory', models.ForeignKey(orm[u'products.productcategory'], null=False))
        ))
        db.create_unique(m2m_table_name, ['product_id', 'productcategory_id'])

        # Adding M2M table for field related on 'Product'
        m2m_table_name = db.shorten_name(u'products_product_related')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('from_product', models.ForeignKey(orm[u'products.product'], null=False)),
            ('to_product', models.ForeignKey(orm[u'products.product'], null=False))
        ))
        db.create_unique(m2m_table_name, ['from_product_id', 'to_product_id'])

        # Adding model 'ProductImage'
        db.create_table(u'products_productimage', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('image', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['filer.Image'], null=True, blank=True)),
            ('sorting', self.gf('django.db.models.fields.PositiveIntegerField')(default=0)),
            ('product', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['products.Product'])),
        ))
        db.send_create_signal(u'products', ['ProductImage'])


    def backwards(self, orm):
        # Deleting model 'ProductAttributeTypeTranslation'
        db.delete_table(u'products_productattributetypetranslation')

        # Deleting model 'ProductAttributeType'
        db.delete_table(u'products_productattributetype')

        # Removing M2M table for field values on 'ProductAttributeType'
        db.delete_table(db.shorten_name(u'products_productattributetype_values'))

        # Deleting model 'ProductAttributeValue'
        db.delete_table(u'products_productattributevalue')

        # Deleting model 'ProductAttributeFilter'
        db.delete_table(u'products_productattributefilter')

        # Removing M2M table for field attributes on 'ProductAttributeFilter'
        db.delete_table(db.shorten_name(u'products_productattributefilter_attributes'))

        # Removing M2M table for field categories on 'ProductAttributeFilter'
        db.delete_table(db.shorten_name(u'products_productattributefilter_categories'))

        # Deleting model 'ProductAttribute'
        db.delete_table(u'products_productattribute')

        # Deleting model 'ProductCategoryTranslation'
        db.delete_table(u'products_productcategorytranslation')

        # Deleting model 'ProductCategory'
        db.delete_table(u'products_productcategory')

        # Removing M2M table for field attribute_types on 'ProductCategory'
        db.delete_table(db.shorten_name(u'products_productcategory_attribute_types'))

        # Deleting model 'ProductTranslation'
        db.delete_table(u'products_producttranslation')

        # Deleting model 'Product'
        db.delete_table(u'products_product')

        # Removing M2M table for field categories on 'Product'
        db.delete_table(db.shorten_name(u'products_product_categories'))

        # Removing M2M table for field related on 'Product'
        db.delete_table(db.shorten_name(u'products_product_related'))

        # Deleting model 'ProductImage'
        db.delete_table(u'products_productimage')


    models = {
        u'auth.group': {
            'Meta': {'object_name': 'Group'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        u'auth.permission': {
            'Meta': {'ordering': "(u'content_type__app_label', u'content_type__model', u'codename')", 'unique_together': "((u'content_type', u'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['contenttypes.ContentType']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        u'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        u'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'filer.file': {
            'Meta': {'object_name': 'File'},
            '_file_size': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'folder': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'all_files'", 'null': 'True', 'to': "orm['filer.Folder']"}),
            'has_all_mandatory_data': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_public': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'modified_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'}),
            'original_filename': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'owner': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'owned_files'", 'null': 'True', 'to': u"orm['auth.User']"}),
            'polymorphic_ctype': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'polymorphic_filer.file_set'", 'null': 'True', 'to': u"orm['contenttypes.ContentType']"}),
            'sha1': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '40', 'blank': 'True'}),
            'uploaded_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'})
        },
        'filer.folder': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('parent', 'name'),)", 'object_name': 'Folder'},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            u'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'modified_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'owner': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'filer_owned_folders'", 'null': 'True', 'to': u"orm['auth.User']"}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['filer.Folder']"}),
            u'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'uploaded_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'})
        },
        'filer.image': {
            'Meta': {'object_name': 'Image', '_ormbases': ['filer.File']},
            '_height': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            '_width': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'author': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'date_taken': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'default_alt_text': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'default_caption': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'file_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['filer.File']", 'unique': 'True', 'primary_key': 'True'}),
            'must_always_publish_author_credit': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'must_always_publish_copyright': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'subject_location': ('django.db.models.fields.CharField', [], {'default': 'None', 'max_length': '64', 'null': 'True', 'blank': 'True'})
        },
        u'products.product': {
            'Meta': {'object_name': 'Product'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'archived': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['products.ProductCategory']", 'null': 'True', 'blank': 'True'}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'date_updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'discount': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'featured': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'long_description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'long_title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'price': ('django.db.models.fields.DecimalField', [], {'max_digits': '8', 'decimal_places': '2'}),
            'price_discount': ('django.db.models.fields.DecimalField', [], {'default': '0', 'max_digits': '8', 'decimal_places': '2'}),
            'related': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['products.Product']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'}),
            'sold': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'sold_count': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'products.productattribute': {
            'Meta': {'object_name': 'ProductAttribute'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'attributes'", 'null': 'True', 'to': u"orm['products.Product']"}),
            'type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['products.ProductAttributeType']", 'null': 'True'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'})
        },
        u'products.productattributefilter': {
            'Meta': {'ordering': "('order_index', 'name')", 'object_name': 'ProductAttributeFilter'},
            'attributes': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['products.ProductAttributeType']", 'null': 'True', 'blank': 'True'}),
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'blank': 'True', 'related_name': "'filters'", 'null': 'True', 'symmetrical': 'False', 'to': u"orm['products.ProductCategory']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'order_index': ('django.db.models.fields.IntegerField', [], {'default': '0'})
        },
        u'products.productattributetype': {
            'Meta': {'object_name': 'ProductAttributeType'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'values': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['products.ProductAttributeValue']", 'symmetrical': 'False'})
        },
        u'products.productattributetypetranslation': {
            'Meta': {'object_name': 'ProductAttributeTypeTranslation'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lang': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'related': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': u"orm['products.ProductAttributeType']"})
        },
        u'products.productattributevalue': {
            'Meta': {'object_name': 'ProductAttributeValue'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['products.ProductAttributeType']", 'null': 'True'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'products.productcategory': {
            'Meta': {'ordering': "['order_index']", 'object_name': 'ProductCategory'},
            'allow_filtering': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'attribute_types': ('django.db.models.fields.related.ManyToManyField', [], {'blank': 'True', 'related_name': "'categories'", 'null': 'True', 'symmetrical': 'False', 'to': u"orm['products.ProductAttributeType']"}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'date_updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['filer.Image']", 'null': 'True', 'blank': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            u'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'order_index': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'parent': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': u"orm['products.ProductCategory']"}),
            u'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'}),
            u'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        u'products.productcategorytranslation': {
            'Meta': {'object_name': 'ProductCategoryTranslation'},
            'description': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lang': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'related': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': u"orm['products.ProductCategory']"}),
            'slug': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'})
        },
        u'products.productimage': {
            'Meta': {'ordering': "('-sorting',)", 'object_name': 'ProductImage'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['filer.Image']", 'null': 'True', 'blank': 'True'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['products.Product']"}),
            'sorting': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'})
        },
        u'products.producttranslation': {
            'Meta': {'object_name': 'ProductTranslation'},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lang': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'long_description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'long_title': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'related': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': u"orm['products.Product']"}),
            'slug': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['products']


import os
import sys
from cratis.env import load_env


def cratis_cmd():
    """
    Command that executes django ./manage.py task + adds cratis wrapping things
    """

    os.environ.setdefault("CRATIS_APP_PATH", os.getcwd())
    os.environ.setdefault('DJANGO_CONFIGURATION', 'Dev')

    load_env()

    from configurations.management import execute_from_command_line

    execute_from_command_line(sys.argv)



from urllib import urlencode
from django.core.urlresolvers import reverse
from django import forms
from django.http import HttpResponseRedirect, HttpResponse
from django.shortcuts import get_object_or_404, render_to_response
from django.template import RequestContext
from django.views.decorators.cache import never_cache
from django.views.decorators.csrf import csrf_exempt
from paypal.pro.exceptions import PayPalFailure
from paypal.pro.fields import CountryField, CreditCardField, CreditCardExpiryField, CreditCardCVV2Field
from paypal.pro.forms import ConfirmForm
from paypal.pro.helpers import SANDBOX_ENDPOINT, ENDPOINT, PayPalWPP, VERSION
from cratis.app.core.settings import APP_SETTINGS
from cratis.app.ecommerce.payment.models import PaymentMethod
from paypal.pro.views import PayPalPro, SANDBOX_EXPRESS_ENDPOINT, EXPRESS_ENDPOINT
from cratis.app.ecommerce.orders.models import Order



class PayPalView(PayPalWPP):

    def __init__(self, request, params):
        """Required - USER / PWD / SIGNATURE / VERSION"""
        self.request = request
        if params['TEST']:
            self.endpoint = SANDBOX_ENDPOINT
        else:
            self.endpoint = ENDPOINT

        self.signature_values = {
            'USER': params['USER'],
            'PWD': params['PASSWORD'],
            'SIGNATURE': params['SIGNATURE'],
            'VERSION': params['VERSION'],
        }
        self.signature = urlencode(self.signature_values) + "&"


class PaymentForm(forms.Form):
    """Form used to process direct payments."""
    firstname = forms.CharField(255, label="First Name")
    lastname = forms.CharField(255, label="Last Name")
    street = forms.CharField(255, label="Street Address")
    city = forms.CharField(255, label="City")
    state = forms.CharField(255, label="State")
    countrycode = CountryField(label="Country", initial="US")
    zip = forms.CharField(32, label="Postal / Zip Code")
    acct = CreditCardField(label="Credit Card Number")
    expdate = CreditCardExpiryField(label="Expiration Date")
    cvv2 = CreditCardCVV2Field(label="Card Security Code")

    def process(self, request, item):
        """Process a PayPal direct payment."""
        wpp = PayPalView(request, params=PaymentForm.cc_config)
        params = self.cleaned_data
        params['creditcardtype'] = self.fields['acct'].card_type
        params['expdate'] = self.cleaned_data['expdate'].strftime("%m%Y")
        params['ipaddress'] = request.META.get("REMOTE_ADDR", "")
        params.update(item)

        try:
            # Create single payment:
            if 'billingperiod' not in params:
                nvp_obj = wpp.doDirectPayment(params)
            # Create recurring payment:
            else:
                nvp_obj = wpp.createRecurringPaymentsProfile(params, direct=True)
        except PayPalFailure:
            return False
        return True



class PayPalProView(PayPalPro):
    def __init__(self, config=None, item=None, payment_form_cls=PaymentForm, payment_template="pro/payment.html",
                 confirm_form_cls=ConfirmForm, confirm_template="pro/confirm.html", success_url="?success",
                 fail_url=None, context=None, form_context_name="form"):

        config['VERSION'] = VERSION
        self.cc_config = config

        PaymentForm.cc_config = config

        super(PayPalProView, self).__init__(item, payment_form_cls, payment_template, confirm_form_cls,
                                            confirm_template, success_url, fail_url, context, form_context_name)

    def get_endpoint(self):
        if self.cc_config['TEST']:
            return SANDBOX_EXPRESS_ENDPOINT
        else:
            return EXPRESS_ENDPOINT

    def redirect_to_express(self):
        """
        First step of ExpressCheckout. Redirect the request to PayPal using the
        data returned from setExpressCheckout.
        """
        wpp = PayPalView(self.request, params=self.cc_config)

        try:
            nvp_obj = wpp.setExpressCheckout(self.item)
        except PayPalFailure as e:
            self.context['errors'] = self.errors['paypal']
            return self.render_payment_form()
        else:
            pp_params = dict(token=nvp_obj.token, AMT=self.item['amt'],
                             RETURNURL=self.item['returnurl'],
                             CANCELURL=self.item['cancelurl'])
            pp_url = self.get_endpoint() % urlencode(pp_params)
            return HttpResponseRedirect(pp_url)

    def render_confirm_form(self):
        """
        Second step of ExpressCheckout. Display an order confirmation form which
        contains hidden fields with the token / PayerID from PayPal.
        """
        initial = dict(token=self.request.GET['token'], PayerID=self.request.GET['PayerID'])
        self.context[self.form_context_name] = self.confirm_form_cls(initial=initial)
        return render_to_response(self.confirm_template, self.context, RequestContext(self.request))

    def validate_confirm_form(self):
        """
        Third and final step of ExpressCheckout. Request has pressed the confirmation but
        and we can send the final confirmation to PayPal using the data from the POST'ed form.
        """
        wpp = PayPalView(self.request, params=self.cc_config)
        pp_data = dict(token=self.request.POST['token'], payerid=self.request.POST['PayerID'])
        self.item.update(pp_data)

        # @@@ This check and call could be moved into PayPalWPP.
        try:
            if self.is_recurring():
                nvp_obj = wpp.createRecurringPaymentsProfile(self.item)
            else:
                nvp_obj = wpp.doExpressCheckoutPayment(self.item)
        except PayPalFailure:
            self.context['errors'] = self.errors['processing']
            return self.render_payment_form()
        else:
            return HttpResponseRedirect(self.success_url)


def paypal_view_data(request, method):

    payment = get_object_or_404(PaymentMethod, slug=method)
    config = payment.behavior().config

    order = Order.objects.get(pk=request.session['order_id'])

    detalisation = order.get_detalisation()
    host = request.META['HTTP_HOST']

    item = {"amt": detalisation['full_total'],  # amount to charge for item
            "inv": order.id, # unique tracking variable paypal
            "cart": order.cart,
            "currencycode": APP_SETTINGS['currency'].upper(),
            #            "custom": "tracking",       # custom tracking variable for you
            "cancelurl": "http://%s%s" % (host, reverse('orders_checkout')), # Express checkout cancel url
            "returnurl": "http://%s/payment/paypal/confirm" % host}  # Express checkout return url

    i = 0
    for row in order.cart.items.all():
        item['L_NAME' + str(i)] = row.product.title
        item['L_AMT' + str(i)] = str(row.unit_price)
        item['L_QTY' + str(i)] = row.quantity
        if row.delivery_method:
            i += 1
            item['L_NAME' + str(i)] = 'Delivery of ' + row.product.title + ' with %s' % row.delivery_method.name
            item['L_AMT' + str(i)] = str(row.delivery_method.delivery_price)
            item['L_QTY' + str(i)] = row.quantity
        i += 1

    #return PayPalPro(item=item, success_url=reverse('cratis.app.ecommerce.orders.views.confirm'))
    return PayPalProView(item=item, success_url=reverse('cratis.app.ecommerce.orders.views.confirm'), config=config)


@never_cache
def payment_start(request, method):
    ppp = paypal_view_data(request, method)
    return ppp(request)


@csrf_exempt
@never_cache
def payment_confirm(request, method):
    ppp = paypal_view_data(request, method)
    return ppp(request)



import hashlib
import re
import time

from django.core.urlresolvers import reverse
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render

from cratis.app.ecommerce.orders.models import Order
from cratis.app.ecommerce.payment.common import log_payment
from cratis.app.ecommerce.payment.crypto import ssl_sign, load_pem_private_key, load_pem_public_key, ssl_verify, load_pem_cert_public_key
from cratis.app.ecommerce.payment.views import PaymentView


__author__ = 'alex'

def sha1(string):
    return hashlib.sha1(string).hexdigest()

def md5(string):
    return hashlib.md5(string).hexdigest()


class PangalinkCallback(PaymentView):

    def bad_payment(self, request):
        if 'fail_url' in request.session:
            return HttpResponseRedirect(request.session['fail_url'])
        else:
            return HttpResponseRedirect(reverse('orders_checkout'))

    def post(self, request, *args, **kwargs):

        method = self.load_method(kwargs['method'])
        settings = method.behavior().config

        log_payment(request, 'pangalink_' + kwargs['method'], 'pay_callback')

        if request.POST['VK_SERVICE'] != '1101':
            log_payment(request, 'pangalink', 'pay_cancel')

            return self.bad_payment(request)

        mac_data = ''
        for field in ['VK_SERVICE', 'VK_VERSION', 'VK_SND_ID',
                'VK_REC_ID', 'VK_STAMP', 'VK_T_NO', 'VK_AMOUNT', 'VK_CURR',
                'VK_REC_ACC', 'VK_REC_NAME', 'VK_SND_ACC', 'VK_SND_NAME',
                'VK_REF', 'VK_MSG', 'VK_T_DATE']:
            v = request.POST[field]
            vlen = len(v)
            mac_data += str(vlen).zfill(3) + v

        public_key = load_pem_cert_public_key(settings['pubkey'])

        if ssl_verify(mac_data.encode('utf-8'), request.POST['VK_MAC'].decode('base64'), public_key):

            ecuno = request.POST['VK_STAMP']

            order_id = int(ecuno) - 100000

            log_payment(request, 'pangalink', 'pay_success')

            order = Order.objects.get(pk=order_id)
            order.mark_paid()

            return HttpResponseRedirect(reverse('cratis.app.ecommerce.orders.views.confirm'))

        else:

            print request.POST['VK_MAC']
            #return self.bad_payment(request)



class PangalinkCancel(PaymentView):
    def post(self, request, *args, **kwargs):
        log_payment(request, 'pangalink', 'pay_cancel')

        return HttpResponseRedirect(reverse('orders_checkout'))

class PangalinkStart(PaymentView):

    def get(self, request, *args, **kwargs):

        method = self.load_method(kwargs['method'])
        settings = method.behavior().config

        order = Order.objects.get(pk=request.session['order_id'])

        detalisation = order.get_detalisation()

        order_total = detalisation['full_total']
        order_id = order.id


        oid = settings['id']

        ecuno = str(order_id + 100000)
        eamount = str(order_total)
        feedbackurl = 'http://' + request.META['HTTP_HOST'] + reverse('pangalink_payment_callback',
                                                                      kwargs={'method': method.slug})
        cancelurl = 'http://' + request.META['HTTP_HOST'] + reverse('pangalink_payment_callback',
                                                                      kwargs={'method': method.slug})

        # padding
        feedbackurl = feedbackurl.ljust(128)
        ecuno = ecuno.zfill(12)
        eamount = eamount.zfill(12)

        data = {
            'VK_SERVICE': '1001',
            'VK_VERSION': '008',
            'VK_SND_ID': oid,
            'VK_STAMP': ecuno,
            'VK_AMOUNT': eamount,
            'VK_CURR': 'EUR',
            'VK_ACC': settings['account'],
            'VK_NAME': settings['owner'],
            'VK_REF': '',
            'VK_MSG': 'Order id ' + str(order_id),
            'VK_RETURN': feedbackurl,
            'VK_ENCODING': 'utf-8',
        }

        mac_data = ''
        for field in ['VK_SERVICE', 'VK_VERSION', 'VK_SND_ID',
                'VK_STAMP', 'VK_AMOUNT', 'VK_CURR',
                'VK_ACC', 'VK_NAME', 'VK_REF', 'VK_MSG']:
            v = data[field]
            vlen = len(v)
            mac_data += str(vlen).zfill(3) + v

        signed = ssl_sign(mac_data.encode('utf-8'), load_pem_private_key(settings['pkey']))

        data['VK_MAC'] = re.sub('\s+', '', signed.encode('base64'))

        log_payment(request, 'pangalink', 'pay_start', data)

        return render(request, 'payment/post_redirect.html', {'url': settings['url'], 'fields': data.items()})

        #'https://pangalink.net/banklink/ec?' + send_data
        #return HttpResponseRedirect('?' + send_data)





from django.conf.urls import url, patterns, include
from cratis.app.i18n.utils import localize_url as _


urlpatterns = patterns('',

    url(_(r'^profile/$'), 'cratis.app.profile.views.profile', name='profile')
)



from cratis.features import Feature


class Debug(Feature):

    def get_required_packages(self, cls):
        return 'django-debug-toolbar',

    def configure_settings(self, cls):
        if cls.DEBUG:
            self.append_apps(cls, ['debug_toolbar'])



from voluptuous import Required, Schema
from cratis.app.ecommerce.payment.common import Payment


class PaytrailPayment(Payment):

    actions_template = 'payment/paytrail_actions.html'

    def schema(self):
        return Schema({
            'secret': str,
            'id': str
        }, required=True)

    def require_payment(self):
        return True





from django.conf.urls.defaults import patterns, url
from django.views.decorators.cache import never_cache
from django.views.decorators.csrf import csrf_exempt
from cratis.app.ecommerce.payment.dibs.views import DibsStart, DibsAccept, DibsCancel, DibsCallback

urlpatterns = patterns('cratis.app.ecommerce.payment.dibs.views',
    url(r'^(?P<method>[^\\]+)/start', never_cache(DibsStart.as_view()), name='dibs_payment_start'),
    url(r'^(?P<method>[^\\]+)/accept', csrf_exempt(never_cache(DibsAccept.as_view())), name='dibs_payment_accept'),
    url(r'^(?P<method>[^\\]+)/cancel', csrf_exempt(never_cache(DibsCancel.as_view())), name='dibs_payment_cancel'),
    url(r'^(?P<method>[^\\]+)/callback', csrf_exempt(never_cache(DibsCallback.as_view())), name='dibs_payment_callback'),
)





from voluptuous import Required, Schema
from cratis.app.ecommerce.payment.common import Payment


class PangalinkPayment(Payment):

    actions_template = 'payment/pangalink_actions.html'

    def schema(self):
        return Schema({
            'pkey': self.valid_key(),
            'pubkey': self.valid_key(),
            'account': str,
            'owner': basestring,
            'id': str,
            'url': str
        }, required=True)

    def require_payment(self):
        return True






from django.db import models
from django.forms.widgets import TextInput
# from suit_redactor.widgets import RedactorWidget
# from chosen import widgets as chosenwidgets


default_overrides = {
    models.CharField: {'widget': TextInput(attrs={'class': 'span5'})},
    # models.TextField: {'widget': RedactorWidget(editor_options={'lang': 'en'})},
    # models.ForeignKey: {'widget': LinkedSelect},
}

def fix_translations(modeladmin, request, queryset):
    for obj in queryset:
        modeladmin.fix_translations(obj)
fix_translations.short_description = "Fix empty translations"




from collections import namedtuple, OrderedDict
import hashlib
import time

from django.core.urlresolvers import reverse
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render
from cratis.app.core.settings import APP_SETTINGS

from cratis.app.ecommerce.orders.models import Order
from cratis.app.ecommerce.payment.common import log_payment
from cratis.app.ecommerce.payment.crypto import ssl_sign, load_pem_private_key, load_pem_public_key, ssl_verify
from cratis.app.ecommerce.payment.views import PaymentView


__author__ = 'alex'


def sha1(string):
    return hashlib.sha1(string).hexdigest()


def md5(string):
    return hashlib.md5(string).hexdigest()


class PaytrailAccept(PaymentView):
    def get(self, request, *args, **kwargs):
        log_payment(request, 'paytrail', 'pay_accept')

        method = self.load_method(kwargs['method'])
        settings = method.behavior().config

        # skip validation
        

        order_id = request.GET['ORDER_NUMBER']
        timestamp = request.GET['TIMESTAMP']
        paid = request.GET['PAID']
        method = request.GET['METHOD']
        authcode = request.GET['RETURN_AUTHCODE']

        mac_data = '|'.join((order_id, timestamp, paid, method, settings['secret']))

        if md5(mac_data).upper() != authcode:
                return HttpResponse('Bad signature. Can not accpet payment.', None, 403)

        order = Order.objects.get(pk=order_id)
        order.mark_paid()

        return HttpResponseRedirect(reverse('cratis.app.ecommerce.orders.views.confirm'))

class PaytrailCancel(PaymentView):
    def post(self, request, *args, **kwargs):
        log_payment(request, 'paytrail', 'pay_cancel')

        #    order_id = request.GET['orderid']
        #    order = Order.objects.get(order_id)
        #    order.mark_paid()

        return HttpResponseRedirect(reverse('orders_checkout'))


class PaytrailCallback(PaymentView):
    def post(self, request, *args, **kwargs):
        log_payment(request, 'paytrail', 'pay_callback')

        # skip validation
        order_id = request.GET['orderid']
        order = Order.objects.get(order_id)
        order.mark_paid()

        return HttpResponse('ok')


class PaytrailStart(PaymentView):
    def get(self, request, *args, **kwargs):
        method = self.load_method(kwargs['method'])
        settings = method.behavior().config

        order = Order.objects.get(pk=request.session['order_id'])

        detalisation = order.get_detalisation()

        order_total = detalisation['full_total']

        data = OrderedDict()
        data['MERCHANT_ID'] = settings['id']
        data['AMOUNT'] = str(order_total)
        data['ORDER_NUMBER'] = str(order.id)
        data['REFERENCE_NUMBER'] = ''
        data['ORDER_DESCRIPTION'] = ''
        data['CURRENCY'] = 'EUR'
        data['RETURN_ADDRESS'] = 'http://' + request.META['HTTP_HOST'] + \
                          reverse('paytrail_payment_accept', kwargs={'method': method.slug})
        data['CANCEL_ADDRESS'] = 'http://' + request.META['HTTP_HOST'] + \
                          reverse('paytrail_payment_cancel', kwargs={'method': method.slug})
        data['PENDING_ADDRESS'] = ''
        data['NOTIFY_ADDRESS'] = 'http://' + request.META['HTTP_HOST'] + \
                          reverse('paytrail_payment_callback', kwargs={'method': method.slug})

        data['TYPE'] = 'S1'
        data['CULTURE'] = 'en_US'
        data['PRESELECTED_METHOD'] = ''
        data['MODE'] = '1'
        data['VISIBLE_METHODS'] = ''
        data['GROUP'] = ''


#6pKF4jkv97zmqBJ3ZL8gUw5DfT2NMQ|13466|99.90|123456||Testitilaus|EUR|http://www.esimerkki.fi/success|http://www.esimerkki.fi/cancel||http://www.esimerkki.fi/notify|S1|fi_FI|1||
#6pKF4jkv97zmqBJ3ZL8gUw5DfT2NMQ|13466|99.90|123456||Testitilaus|EUR|http://www.esimerkki.fi/success|http://www.esimerkki.fi/cancel||http://www.esimerkki.fi/notify|S1|fi_FI||1||

        #
        #data['MERCHANT_ID'] = settings['id']
        #data['AMOUNT'] = '99.90'
        #data['ORDER_NUMBER'] = '123456'
        #data['REFERENCE_NUMBER'] = ''
        #data['ORDER_DESCRIPTION'] = 'Testitilaus'
        #data['CURRENCY'] = 'EUR'
        #data['RETURN_ADDRESS'] = 'http://www.esimerkki.fi/success'
        #data['CANCEL_ADDRESS'] = 'http://www.esimerkki.fi/cancel'
        #data['PENDING_ADDRESS'] = ''
        #data['NOTIFY_ADDRESS'] = 'http://www.esimerkki.fi/notify'
        #
        #data['TYPE'] = 'S1'
        #data['CULTURE'] = 'fi_FI'
        #data['PRESELECTED_METHOD'] = ''
        #data['MODE'] = '1'
        #data['VISIBLE_METHODS'] = ''
        #data['GROUP'] = ''

        mac_data = settings['secret'] + '|' + '|'.join(data.values())

        mac = md5(mac_data).upper()

        data['AUTHCODE'] = mac

        log_payment(request, 'paytrail', 'pay_start', data)

        url = 'https://payment.verkkomaksut.fi/'

        return render(request, 'payment/post_redirect.html', {'url': url, 'fields': data.items()})




import os
import sys
import yaml


def _find_project_env(path):
    env_file_name = '%s/%s_env.yml' % (os.path.dirname(path), os.path.basename(path))
    env_file_name_dot = '%s/.%s_env.yml' % (os.path.dirname(path), os.path.basename(path))

    if os.path.exists(env_file_name):
        return path, env_file_name
    elif os.path.exists(env_file_name_dot):
        return path, env_file_name_dot
    elif path != '/':
        return _find_project_env(os.path.dirname(path))
    else:
        return None, None


def _format_val(val):
    return str(val)


def load_env():
    """
    Loads environment variables from project folder ../folder_name_env.yml file
    """
    app_dir, _file = _find_project_env(os.getcwd())
    if _file:
        os.environ["CRATIS_APP_PATH"] = app_dir

        with open(_file) as f:
            for key, val in yaml.load(f).iteritems():
                val = _format_val(val)
                os.environ[key] = val

    sys.path += (os.environ['CRATIS_APP_PATH'], )

    if os.path.exists(os.environ['CRATIS_APP_PATH'] + os.sep + 'settings.py'):
        os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
    else:
        os.environ.setdefault("DJANGO_SETTINGS_MODULE", "cratis.settings")


from django.db.models import Count
#from cratis.app.ecommerce.shopping_cart.models import DeliveryMethod
from cratis.app.ecommerce.products.models import ProductCategory

def shop_context(request):
    """
    @type context: HttpRequest
    """

    if request.path[0:7] == '/admin/':
        return {}

    context = {
        'categories': ProductCategory.objects.all(),
        'categories_count': dict([(cat.id, cat.product__count) for cat in ProductCategory.objects.filter(product__active=True).annotate(Count('product'))]),
        # 'delivery_methods': DeliveryMethod.objects.filter(enabled=True)
    }
    return context


from django.conf.urls.defaults import patterns, url

# Uncomment the next two lines to enable the admin:
from cratis.app.core.common.i18n import localize_url as _
from cratis.app.ecommerce.orders.views import CheckoutView, CheckoutDoneView, OrderStatusView, PaymentWaitView

urlpatterns = patterns('cratis.app.ecommerce.orders.views',

    url(r'^checkout/$',
        CheckoutView.as_view(),
        name='orders_checkout'
    ),
    url(_(r'^checkout/done$'),
        CheckoutDoneView.as_view(),
        name='orders_checkout_done'
    ),
    url(_(r'^checkout/payment/wait$'),
        PaymentWaitView.as_view(),
        name='orders_checkout_pay_wait'
    ),
    url(_(r'^checkout/status/(?P<order_id>[0-9]+)/(?P<hash>[a-f0-9]+)$'),
        OrderStatusView.as_view(),
        name='orders_status'
    ),

    url(r'^checkout/set_delivery', 'set_delivery'),
    url(_(r'^checkout/set_payment'), 'set_payment'),
    url(r'^checkout/validate', 'validate'),
#    url(r'^checkout/smartpost', 'set_smartpost_box'),
    url(r'^checkout/address', 'update_address'),
    url(r'^checkout/contacts', 'update_contacts'),
    url(_(r'^checkout/confirm'), 'confirm'),
    url(r'^checkout/payment/response', 'payment_response'),
    url(_(r'^checkout/payment/check'), 'payment_check')

)



from django.core.exceptions import ValidationError
from django.core.validators import RegexValidator
from django.db import models
from django.db.models.fields import DateTimeField
from django import forms
from filer.fields.image import FilerImageField
from voluptuous import MultipleInvalid
import yaml

from cratis.app.core.common.fields import YamlFancyField
from cratis.app.core.common.translate import TranslatableModelMixin
from cratis.app.ecommerce.payment.methods import get_payment_method_selection, get_payment_method
from django.utils.translation import ugettext_lazy as _

class PaymentLog(models.Model):
    date_created = DateTimeField(auto_now_add=True)
    date_updated = DateTimeField(auto_now=True)

    module = models.CharField(max_length=50, null=True, blank=True, default='')
    user_id = models.CharField(max_length=50, null=True, blank=True, default='')
    user_ip = models.CharField(max_length=50, null=True, blank=True, default='')
    operation = models.CharField(max_length=255, null=True, blank=True, default='')
    url = models.CharField(max_length=255, null=True, blank=True, default='')
    request_get = models.TextField(blank=True, null=True, default='')
    request_post = models.TextField(blank=True, null=True, default='')
    data = models.TextField(blank=True, null=True, default='')


class PaymentMethodTranslation(models.Model):
    lang = models.CharField(max_length=2, editable=False)
    name = models.CharField(max_length=150, null=True, blank=True)
    description = models.TextField(blank=True, null=True, default='')

    related = models.ForeignKey('PaymentMethod', null=True, related_name='translations')

class PaymentMethodKey(models.Model):
    name = models.CharField(max_length=150, null=True)
    payment = models.ForeignKey('PaymentMethod', related_name='keys')
    body = models.TextField(blank=True, null=True, default='')

    class Meta:
        unique_together = (("name", "payment"),)

slug_validator = RegexValidator(regex='^[^\d/][^/]+$',
                                message=_('Slug should not start with digit and contain "/" character'))

class PaymentMethod(TranslatableModelMixin, models.Model):
    method = models.CharField(max_length=20, choices=get_payment_method_selection(), null=True)
    enabled = models.BooleanField(default=False, verbose_name=_('Enabled'))

    slug = models.CharField(max_length=255, verbose_name=_('slug'), default='', blank=True, validators=[slug_validator])

    logo = FilerImageField(null=True, blank=True, related_name='payment_method_logo')
    picture = FilerImageField(null=True, blank=True, related_name='payment_method_picture')
    name = models.CharField(max_length=150, null=True)
    description = models.TextField(blank=True, default='')

    sorting = models.PositiveIntegerField(default=0)

    config = YamlFancyField(blank=True, null=True)

    def clean(self):
        try:
            method = self.behavior()
        except yaml.MarkedYAMLError as e:
            raise ValidationError('Config yaml parse error: ' + str(e))
        except MultipleInvalid as e:
            raise ValidationError('Config is not valid: ' + str(e))
        if not method:
            raise ValidationError('Payment method is incorrect.')

    def behavior(self):
        if not self.method:
            return None
        return get_payment_method(self.method, self.parse_config(), self.get_keys())

    def parse_config(self):
        return yaml.load(self.config)

    def get_keys(self):
        return dict([(x.name, x.body) for x in self.keys.all()])

    def __unicode__(self):
        return self.name

    @staticmethod
    def get_translation_class():
        return PaymentMethodTranslation

    class Meta:
        ordering = ('sorting', )


import hashlib
import json
import re
import time

from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.template import RequestContext

from cratis.app.ecommerce.orders.models import Order
from cratis.app.ecommerce.payment.common import log_payment
from cratis.app.ecommerce.payment.views import PaymentView


class VoucherStart(PaymentView):

    def post(self, request, *args, **kwargs):

        method = self.load_method(kwargs['method'])

        log_payment(request, 'voucher_' + kwargs['method'], 'pay_callback')

        order = Order.objects.get(pk=request.session['order_id'])
        order.comment = 'Voucher: %s phone: %s email: %s' % (request.POST['voucher_code'], request.POST['phone'], request.POST['email'])
        order.mark_confirmed()

        return HttpResponseRedirect(reverse('cratis.app.ecommerce.orders.views.confirm'))





from django.conf.urls.defaults import patterns, url
from django.views.decorators.cache import never_cache
from django.views.decorators.csrf import csrf_exempt
from cratis.app.ecommerce.payment.paytrail.views import PaytrailStart, PaytrailCallback, PaytrailAccept, PaytrailCancel


urlpatterns = patterns('cratis.app.ecommerce.payment.paytrail.views',
    url(r'^(?P<method>[^\\]+)/start', never_cache(PaytrailStart.as_view()), name='paytrail_payment_start'),
    url(r'^(?P<method>[^\\]+)/accept', csrf_exempt(never_cache(PaytrailAccept.as_view())), name='paytrail_payment_accept'),
    url(r'^(?P<method>[^\\]+)/cancel', csrf_exempt(never_cache(PaytrailCancel.as_view())), name='paytrail_payment_cancel'),
    url(r'^(?P<method>[^\\]+)/callback', csrf_exempt(never_cache(PaytrailCallback.as_view())), name='paytrail_payment_callback'),
)






import os
from voluptuous import Schema, Extra, MultipleInvalid
import yaml


class ThemeLoadException(Exception):
    pass


class ThemeNotFoundException(ThemeLoadException):
    pass


class ThemeBadConfigException(ThemeLoadException):
    pass


def validate_config(theme_config):
    Schema({
        'parents': [str],
        'cms_templates': {
            Extra: str
        },
        'template_dirs': [str],
        'asset_dirs': [str]
    })(theme_config)


def load_theme(theme_paths, name, allow_abstract=False):

    if name in theme_paths['themes']:
        theme_path = theme_paths['themes'][name]
    else:
        theme_path = theme_paths['dir'] + os.sep + name

    theme_config_file = theme_path + os.sep + 'theme.yml'

    if not os.path.exists(theme_path):
        raise ThemeNotFoundException("Theme %s do not exist." % theme_path)

    if os.path.exists(theme_config_file):
        theme_config = yaml.load(open(theme_config_file, 'r'))
    else:
        raise ThemeBadConfigException("Theme %s must contain theme.yml." % theme_path)

    try:
        validate_config(theme_config)
    except MultipleInvalid as e:
        raise ThemeBadConfigException("Theme config %s validation error: %s" % (theme_config_file, str(e)))

    """
    Each theme should contain at least one cms template.
    """
    if not theme_config.has_key('abstract') and (not theme_config.has_key('cms_templates') or len(theme_config['cms_templates']) == 0):
        raise ThemeBadConfigException("Theme %s should contain at least one cms template." % theme_path)

    if not allow_abstract and theme_config.has_key('abstract') and theme_config['abstract']:
        raise ThemeBadConfigException("Theme %s is marked as abstract and can not be loaded as main theme." % theme_path)

    theme_config['loaded_themes'] = [name]

    if not 'template_dirs' in theme_config:
        theme_config['template_dirs'] = []
    theme_config['template_dirs'] = [theme_path + os.sep + dir_ for dir_ in theme_config['template_dirs']]

    if not 'asset_dirs' in theme_config:
        theme_config['asset_dirs'] = []
    theme_config['asset_dirs'] = [theme_path + os.sep + dir_ for dir_ in theme_config['asset_dirs']]

    if theme_config.has_key('parents'):
        for parent_ in theme_config['parents']:
            try:
                parent_config = load_theme(theme_paths, parent_, allow_abstract=True)
            except (ThemeNotFoundException, ThemeBadConfigException) as e:
                raise ThemeBadConfigException("Error loading theme \"%s\" parent: %s" % (name, e.message,))


            # update only not existing keys
            parent_config['cms_templates'].update(theme_config['cms_templates'])
            theme_config['cms_templates'] = parent_config['cms_templates']

            theme_config['template_dirs'].extend(parent_config['template_dirs'])
            theme_config['asset_dirs'].extend(parent_config['asset_dirs'])

            theme_config['loaded_themes'] += parent_config['loaded_themes']

    return theme_config




from django.conf import settings
from django.core.urlresolvers import resolve, Resolver404, reverse
from django.utils.translation import get_language, activate



def i18n_context(request):
    """
    @type context: HttpRequest
    """
    all_languages = settings.LANGUAGES
    if len(all_languages) == 1:
        return {}

    if request.path[0:7] == '/admin/':
        return {}

    cur_lang = get_language()
    lang_urls = {}

    try:
        match = resolve(request.path)
    except Resolver404:
        match = None

    switched = False

    for code, name in all_languages:
        if match and match.url_name != 'pages-details-by-slug':
            switched = True
            activate(code)
            rev = reverse(match.url_name, kwargs=match.kwargs)
            lang_urls[code] = rev
        else:
            lang_urls[code] = ('/' if code == settings.MAIN_LANGUAGE else ('/' + code + '/'))

    if switched:
        activate(cur_lang)

    context = {
        'default_language': settings.MAIN_LANGUAGE,
        'lang_urls': lang_urls
    }
    if match:
        context['url_name'] = match.url_name

    return context


from django.contrib.auth.decorators import login_required
from django.views.generic import TemplateView


class ProfileView(TemplateView):
    template_name = 'account/profile.html'

profile = login_required(
    ProfileView.as_view()
)



import hashlib
import time

from django.core.urlresolvers import reverse
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render

from cratis.app.ecommerce.orders.models import Order
from cratis.app.ecommerce.payment.common import log_payment
from cratis.app.ecommerce.payment.crypto import ssl_sign, load_pem_private_key, load_pem_public_key, ssl_verify
from cratis.app.ecommerce.payment.views import PaymentView


__author__ = 'alex'

def sha1(string):
    return hashlib.sha1(string).hexdigest()

def md5(string):
    return hashlib.md5(string).hexdigest()


class KardikeskusCallback(PaymentView):

    def post(self, request, *args, **kwargs):

        method = self.load_method(kwargs['method'])
        settings = method.behavior().config

        log_payment(request, 'kardikeskus_' + kwargs['method'], 'pay_callback')

        oid = settings['id']

        ecuno = request.POST['ecuno']

        receipt_no = request.POST['receipt_no']
        eamount = request.POST['eamount']
        datetime = request.POST['datetime']
        mac = request.POST['mac'].decode('hex')
        respcode = request.POST['respcode']
        msgdata = request.POST['msgdata']
        actiontext = request.POST['actiontext']
        id = request.POST['id']
        ver = request.POST['ver']
        cur = request.POST['cur']

        #ver = '004'
        #eamount = str(order_total)
        #cur = 'EUR'
        #datetime = time.strftime("%Y%m%d%H%M%S")
        #feedbackurl = 'http://' + request.META['HTTP_HOST'] + reverse('kardikeskus_payment_callback',
        #                                                              kwargs={'method': method.slug})
        #delivery = 'S'
        #
        ## padding
        #feedbackurl = feedbackurl.ljust(128)
        #ecuno = ecuno.zfill(12)
        #eamount = eamount.zfill(12)
        #
        #
        #
        #

        data = ''
        data += ver.zfill(3)
        data += id.ljust(10, ' ')
        data += ecuno.zfill(12)
        data += receipt_no.zfill(6)
        data += eamount.zfill(12)
        data += cur.rjust(3, ' ')
        data += respcode
        data += datetime
        data += unicode(msgdata).ljust(40, ' ')
        data += unicode(actiontext).ljust(40, ' ')


        #sprintf("%03s", $ver) . sprintf("%-10s", "$id") .
#sprintf("%012s", $ecuno) . sprintf("%06s", $receipt_no) . sprintf("%012s",
#$eamount) . sprintf("%3s", $cur) . $respcode . $datetime . mb_sprintf("%-40s",
#$msgdata) . mb_sprintf("%-40s", $actiontext);
#

        #print data
        #print mac
        #data = ver+id+ecuno+receipt_no+eamount+cur+respcode+datetime+msgdata+actiontext

        order_id = int(ecuno) - 100000

        #if ssl_verify(data, mac, load_pem_public_key(settings['pubkey'])):
        #
        #    return HttpResponse('okkkk')
        #else:
        #    return HttpResponse('not ok')


        log_payment(request, 'kardikeskus', 'pay_callback')

        # skip validation
        #order_id = request.POST['orderid']
        order = Order.objects.get(pk=order_id)
        order.mark_paid()

        return HttpResponseRedirect(reverse('cratis.app.ecommerce.orders.views.confirm'))


class KardikeskusStart(PaymentView):

    def get(self, request, *args, **kwargs):

        method = self.load_method(kwargs['method'])
        settings = method.behavior().config

        order = Order.objects.get(pk=request.session['order_id'])

        detalisation = order.get_detalisation()

    #    for row in detalisation['rows']:
    #        ulink_order.items.append(UlinkOrderItem(smart_str(row['title']), '', str(row['price'])))

        order_total = int(detalisation['full_total'] * 100)
        order_id = order.id


    #    key = """

    #"""
    #    oid = 'EB00310653'
        oid = settings['id']

        ecuno = str(order_id + 100000)
        ver = '004'
        eamount = str(order_total)
        cur = 'EUR'
        datetime = time.strftime("%Y%m%d%H%M%S")
        feedbackurl = 'http://' + request.META['HTTP_HOST'] + reverse('kardikeskus_payment_callback',
                                                                      kwargs={'method': method.slug})
        delivery = 'S'

        # padding
        feedbackurl = feedbackurl.ljust(128)
        ecuno = ecuno.zfill(12)
        eamount = eamount.zfill(12)

        data = ver + oid + ecuno + eamount + cur + datetime + feedbackurl + delivery

        signed = ssl_sign(data, load_pem_private_key(settings['pkey']))

        mac = signed.encode('hex')

        data = {
            'lang': 'et', # get_language(),
            'action': 'gaf',
            'ver': ver,
            'id': oid,
            'ecuno': ecuno,
            'eamount': eamount,
            'cur': 'EUR',
            'datetime': datetime,
            'charEncoding': 'UTF-8',
            'feedBackUrl': feedbackurl.strip(),
            'delivery': delivery,
            'mac': mac
        }

        log_payment(request, 'kardikeskus', 'pay_start', data)

        return render(request, 'payment/post_redirect.html', {'url': settings['url'], 'fields': data.items()})

        #'https://pangalink.net/banklink/ec?' + send_data
        #return HttpResponseRedirect('?' + send_data)




from django.contrib import admin
from django.forms import TextInput, Textarea
from suit.admin import SortableModelAdmin
from cratis.app.core.common.admin import default_overrides, fix_translations
from cratis.app.core.common.translate import TranslatableAdmin, InlineTranslations
from cratis.app.ecommerce.payment.models import PaymentLog, PaymentMethod, PaymentMethodTranslation, PaymentMethodKey
from django.db import models

class PaymentLogAdmin(admin.ModelAdmin):
    ordering = ('-id',)
    list_display = ('module', 'operation', 'url', 'user_ip', 'user_id', 'date_created')

admin.site.register(PaymentLog, PaymentLogAdmin)


class InlinePaymentMethodTranslation(InlineTranslations):
    model = PaymentMethodTranslation
    suit_classes = 'suit-tab suit-tab-translations'
    formfield_overrides = default_overrides


class InlinePaymentMethodKey(admin.StackedInline):
    model = PaymentMethodKey
    suit_classes = 'suit-tab suit-tab-keys'
    formfield_overrides = {
            models.CharField: {'widget': TextInput(attrs={'class': 'span5'})},
            models.TextField: {'widget': Textarea(attrs={'class': 'span7'})},
    }
    extra = 1


class PaymentMethodAdmin(SortableModelAdmin, TranslatableAdmin):
    formfield_overrides = default_overrides
    inlines = [InlinePaymentMethodTranslation, InlinePaymentMethodKey]
    init_translations = ['name', 'description']
    translation_class = PaymentMethodTranslation
    list_display = ('name', 'method', 'enabled')
    actions = [fix_translations]

    sortable = 'sorting'

    fieldsets = (
        (None, {
            'classes': ('suit-tab suit-tab-general',),
            'fields': (
                'name', 'slug', 'method', 'enabled', 'logo', 'picture', 'description')
        }),
        ('Configuration', {
            'classes': ('suit-tab suit-tab-config',),
            'fields': ('config', )
        })
    )

    suit_form_tabs = (
        ('general', 'General'),
        ('config', 'Configuration'),
        ('keys', 'Keys'),
        ('translations', 'Translations')
    )

    def response_post_save_add(self, request, obj):
        return super(PaymentMethodAdmin, self).response_post_save_add(request, obj)


admin.site.register(PaymentMethod, PaymentMethodAdmin)